@@ -10,9 +10,8 @@ test_that("text has correct dimensions", {
   register_manual_test("test-scale-text.html")
 
   ttf <- fontquiver::font("Liberation", "Sans", "Regular")$ttf
-  metrics <- gdtools::str_metrics("foobar", fontfile = ttf)
-  w <- metrics[["width"]]
-  h <- metrics[["ascent"]]
+  w <- systemfonts::string_width("foobar", path = ttf, index = 0L, res = 1e4) * 72 / 1e4
+  h <- max(vapply(systemfonts::glyph_info("foobar", path = ttf, index = 0L, res = 1e4)$bbox, `[[`, numeric(1), "ymax")) * 72 / 1e4
 
   svglite("test-scale-text.svg", width = w / 72, height = h / 72,
     user_fonts = fontquiver::font_families("Liberation"))
